@@ -2,7 +2,7 @@ package Dancer;
 
 use strict;
 use warnings;
-use Carp 'confess';
+use Carp;
 use Cwd 'abs_path', 'realpath';
 use vars qw($VERSION $AUTHORITY @EXPORT);
 
@@ -31,7 +31,7 @@ use File::Basename 'basename';
 use base 'Exporter';
 
 $AUTHORITY = 'SUKRIA';
-$VERSION   = '1.1999_01';
+$VERSION   = '1.1999_02';
 @EXPORT    = qw(
   after
   any
@@ -133,7 +133,7 @@ sub prefix { Dancer::App->current->set_prefix(@_) }
 sub del     { Dancer::App->current->registry->universal_add('delete',  @_) }
 sub options { Dancer::App->current->registry->universal_add('options', @_) }
 sub put     { Dancer::App->current->registry->universal_add('put',     @_) }
-sub r { warn "'r' is DEPRECATED use qr{} instead"; return {regexp => $_[0]} }
+sub r { carp "'r' is DEPRECATED use qr{} instead"; return {regexp => $_[0]} }
 sub redirect  { Dancer::Helpers::redirect(@_) }
 sub request   { Dancer::SharedData->request }
 sub send_file { Dancer::Helpers::send_file(@_) }
@@ -151,6 +151,7 @@ sub setting {
 sub set_cookie { Dancer::Helpers::set_cookie(@_) }
 
 sub session {
+    croak "Must specify session engine in settings prior to using 'session' keyword" unless setting('session');
     if (@_ == 0) {
         return Dancer::Session->get;
     }
@@ -191,7 +192,7 @@ sub load_app {
     my ($package, $script) = caller;
     _init($script);
     my ($res, $error) = Dancer::ModuleLoader->load($app_name);
-    $res or die "unable to load application $app_name : $error";
+    $res or croak "unable to load application $app_name : $error";
 
     # restore the main application
     Dancer::App->set_running_app('main');
@@ -208,6 +209,7 @@ sub import {
     my ($package, $script) = caller;
 
     strict->import;
+    utf8->import;
     $class->export_to_level(1, $class, @EXPORT);
 
     # if :syntax option exists, don't change settings
@@ -230,7 +232,10 @@ sub start {
     if ($request) {
         return Dancer::Handler->handle_request($request);
     }
-    Dancer::Handler->get_handler()->dance;
+
+    my $handler = Dancer::Handler->get_handler;
+    Dancer::Logger::core("loading handler '".ref($handler)."'");
+    return $handler->dance;
 }
 
 
@@ -269,7 +274,7 @@ sub _init {
     setting logger => 'file';
 
     my ($res, $error) = Dancer::ModuleLoader->use_lib(path(setting('appdir'), 'lib'));
-    $res or die "unable to set libdir : $error";
+    $res or croak "unable to set libdir : $error";
 }
 
 1;
