@@ -2,10 +2,10 @@ package Dancer::Handler::PSGI;
 
 use strict;
 use warnings;
+use Carp;
 use base 'Dancer::Handler';
 
 use Dancer::GetOpt;
-use Dancer::Headers;
 use Dancer::Config;
 use Dancer::ModuleLoader;
 use Dancer::SharedData;
@@ -14,7 +14,7 @@ use Dancer::Logger;
 sub new {
     my $class = shift;
 
-    die "Plack::Request is needed by the PSGI handler"
+    croak "Plack::Request is needed by the PSGI handler"
       unless Dancer::ModuleLoader->load('Plack::Request');
 
     my $self = {};
@@ -22,19 +22,14 @@ sub new {
     return $self;
 }
 
-sub dance {
+sub start {
     my $self = shift;
 
-    my $app = sub {
-        my $env = shift;
-        $self->init_request_headers($env);
-        my $request = Dancer::Request->new($env);
-        $self->handle_request($request);
-    };
+    my $app = $self->psgi_app();
 
     if (Dancer::Config::setting('plack_middlewares')) {
         my $middlewares = Dancer::Config::setting('plack_middlewares');
-        die "Plack::Builder is needed for middlewares support"
+        croak "Plack::Builder is needed for middlewares support"
           unless Dancer::ModuleLoader->load('Plack::Builder');
 
         my $builder = Plack::Builder->new();
@@ -49,10 +44,8 @@ sub dance {
 
 sub init_request_headers {
     my ($self, $env) = @_;
-
     my $plack = Plack::Request->new($env);
-    my $headers = Dancer::Headers->new(headers => $plack->headers);
-    Dancer::SharedData->headers($headers);
+    Dancer::SharedData->headers($plack->headers);
 }
 
 1;
