@@ -2,10 +2,12 @@ package Dancer::Request;
 
 use strict;
 use warnings;
+use Carp;
+
 use Dancer::Object;
-use Dancer::Headers;
 use Dancer::Request::Upload;
 use Dancer::SharedData;
+use Encode;
 use HTTP::Body;
 use URI;
 use URI::Escape;
@@ -38,7 +40,7 @@ sub is_post               { $_[0]->{method} eq 'POST' }
 sub is_get                { $_[0]->{method} eq 'GET' }
 sub is_put                { $_[0]->{method} eq 'PUT' }
 sub is_delete             { $_[0]->{method} eq 'DELETE' }
-sub header                { $_[0]->{headers}->get($_[1]) }
+sub header                { $_[0]->{headers}->header($_[1]) }
 
 # public interface compat with CGI.pm objects
 sub request_method { method(@_) }
@@ -88,7 +90,7 @@ sub new_for_request {
       $class->new({%ENV, PATH_INFO => $path, REQUEST_METHOD => $method});
     $req->{params} = {%{$req->{params}}, %{$params}};
     $req->{body} = $body if defined $body;
-    $req->{headers} = Dancer::Headers->new(headers => $headers) if $headers;
+    $req->{headers} = $headers if $headers;
 
     return $req;
 }
@@ -146,7 +148,7 @@ sub params {
         return $self->{_route_params};
     }
     else {
-        die "Unknown source params \"$source\".";
+        croak "Unknown source params \"$source\".";
     }
 }
 
@@ -193,22 +195,37 @@ sub _init {
 # for this purpose
 sub _set_route_params {
     my ($self, $params) = @_;
+    $params = _decode_params($params);
     $self->{_route_params} = $params;
     $self->_build_params();
 }
 
 sub _set_body_params {
     my ($self, $params) = @_;
+    $params = _decode_params($params);
     $self->{_body_params} = $params;
     $self->_build_params();
 }
 
 sub _set_query_params {
     my ($self, $params) = @_;
+    $params = _decode_params($params);
     $self->{_query_params} = $params;
     $self->_build_params();
 }
 
+sub _decode_params {
+    my ($params) = @_;
+    require Dancer::Config;
+    my $cs = Dancer::Config::setting('charset');
+    if ($cs eq 'UTF-8') {
+        for my $p (keys %{$params}) {
+            $params->{$p} = decode('UTF-8', $params->{$p});
+        }
+    }
+    return $params;
+}
+
 sub _build_request_env {
     my ($self) = @_;
 
@@ -249,6 +266,7 @@ sub _build_params {
         %$previous,                %{$self->{_query_params}},
         %{$self->{_route_params}}, %{$self->{_body_params}},
     };
+
 }
 
 # Written from PSGI specs:
@@ -269,7 +287,7 @@ sub _build_path {
         $path ||= $self->_url_decode($self->{request_uri});
     }
 
-    die "Cannot resolve path" if not $path;
+    croak "Cannot resolve path" if not $path;
     $self->{path} = $path;
 }
 
@@ -381,7 +399,7 @@ sub _read {
         return $buffer;
     }
     else {
-        die "Unknown error reading input: $!";
+        croak "Unknown error reading input: $!";
     }
 }
 
