@@ -2,6 +2,7 @@ package Dancer::Serializer::XML;
 
 use strict;
 use warnings;
+use Carp;
 use Dancer::ModuleLoader;
 use base 'Dancer::Serializer::Abstract';
 
@@ -11,15 +12,13 @@ my $_xs;
 # helpers
 
 sub from_xml {
-    my ($xml) = @_;
     my $s = Dancer::Serializer::XML->new;
-    $s->deserialize($xml);
+    $s->deserialize(@_);
 }
 
 sub to_xml {
-    my ($data) = @_;
     my $s = Dancer::Serializer::XML->new;
-    $s->serialize($data);
+    $s->serialize(@_);
 }
 
 # class definition
@@ -28,22 +27,22 @@ sub loaded { Dancer::ModuleLoader->load('XML::Simple') }
 
 sub init {
     my ($self) = @_;
-    die 'XML::Simple is needed and is not installed'
+    croak 'XML::Simple is needed and is not installed'
       unless $self->loaded;
     $_xs = XML::Simple->new();
 }
 
 sub serialize {
-    my ( $self, $entity ) = @_;
-    $_xs->XMLout( { data => $entity } );
+    my $self = shift;
+    $_xs->XMLout(@_);
 }
 
 sub deserialize {
-    my ( $self, $content ) = @_;
-    $_xs->XMLin($content);
+    my $self = shift;
+    $_xs->XMLin(@_);
 }
 
-sub content_type { 'text/xml' }
+sub content_type {'text/xml'}
 
 1;
 __END__
